@@ -55,22 +55,20 @@ class Freebox(IPlugin):
 				log.msg("idx  :  %s" % (rs['idx']))
 				log.msg("idx sec :  %s" % (int(rs['idx_sec'])))
 				log.msg(" boy  :  %s" % (rs['boy']))
-				if rs['idx_sec'] == "":
-					rs['idx_sec'] == "1"
+				bodies = rs['boy']
+				log.msg("BODIES  :  %s" % (bodies))
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
-					bodies = rs['boy']
-					log.msg("BODIES  :  %s" % (bodies))
-					log.msg("number  :  %s" % (int(rs['idx'])))
-		# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
+					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 					for rx in range (1, int(rs['idx_sec'])): 				
 						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 						log.msg("resp  :  %s" % (resp))
 				else:
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
+					log.msg("resp unique   :  %s" % (resp))
 				
 				
 		if bodies == "":
